@@ -203,7 +203,7 @@ impl PanelState for PreviewState {
     fn with_new_options(
         &mut self,
         _screen: Screen,
-        change_options: &dyn Fn(&mut TreeOptions),
+        change_options: &dyn Fn(&mut TreeOptions) -> &'static str,
         _in_new_panel: bool, // TODO open tree if true
         _con: &AppContext,
     ) -> CmdResult {
@@ -374,9 +374,11 @@ impl PanelState for PreviewState {
                 self.pending_pattern = self.removed_pattern.take();
                 Ok(CmdResult::Keep)
             }
+            Internal::panel_left_no_open => Ok(CmdResult::HandleInApp(Internal::panel_left_no_open)),
             Internal::panel_right if self.filtered_preview.is_some() => {
                 self.on_pattern(InputPattern::none(), app_state, con)
             }
+            Internal::panel_right_no_open => Ok(CmdResult::HandleInApp(Internal::panel_right_no_open)),
             Internal::select_first => {
                 self.mut_preview().select_first();
                 Ok(CmdResult::Keep)
